@@ -1,6 +1,5 @@
-"""
-Defines the abstract base traits of a tox environment.
-"""
+"""Defines the abstract base traits of a tox environment."""
+
 from __future__ import annotations
 
 import fnmatch
@@ -11,30 +10,56 @@ import string
 import sys
 from abc import ABC, abstractmethod
 from contextlib import contextmanager
-from io import BytesIO
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Iterator, List, NamedTuple, Sequence, Set, cast
+from typing import TYPE_CHECKING, Any, NamedTuple, cast
 
-from tox.config.main import Config
-from tox.config.set_env import SetEnv
-from tox.config.sets import CoreConfigSet, EnvConfigSet
-from tox.execute.api import Execute, ExecuteStatus, Outcome, StdinSource
 from tox.execute.request import ExecuteRequest
-from tox.journal import EnvJournal
-from tox.report import OutErr, ToxHandler
 from tox.tox_env.errors import Fail, Recreate, Skip
 from tox.tox_env.info import Info
-from tox.tox_env.installer import Installer
 from tox.util.path import ensure_empty_dir
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator, Sequence
+    from io import BytesIO
+
     from tox.config.cli.parser import Parsed
+    from tox.config.main import Config
+    from tox.config.set_env import SetEnv
+    from tox.config.sets import CoreConfigSet, EnvConfigSet
+    from tox.execute.api import Execute, ExecuteStatus, Outcome, StdinSource
+    from tox.journal import EnvJournal
+    from tox.report import OutErr, ToxHandler
+    from tox.tox_env.installer import Installer
 
 LOGGER = logging.getLogger(__name__)
+# Based on original gitleaks rule named generic-api-key
+# See: https://github.com/gitleaks/gitleaks/blob/master/config/gitleaks.toml#L587
+SECRET_KEYWORDS = [
+    "access",
+    "api",
+    "auth",
+    "client",
+    "cred",
+    "key",
+    "passwd",
+    "password",
+    "private",
+    "pwd",
+    "secret",
+    "token",
+]
+SECRET_ENV_VAR_REGEX = re.compile(".*(" + "|".join(SECRET_KEYWORDS) + ").*", re.IGNORECASE)
+
+
+def redact_value(name: str, value: str) -> str:
+    """Returns a redacted text if the key name looks like a secret."""
+    if SECRET_ENV_VAR_REGEX.match(name):
+        return "*" * len(value)
+    return value
 
 
 class ToxEnvCreateArgs(NamedTuple):
-    """Arguments to pass on when creating a tox environment"""
+    """Arguments to pass on when creating a tox environment."""
 
     conf: EnvConfigSet
     core: CoreConfigSet
@@ -47,7 +72,8 @@ class ToxEnv(ABC):
     """A tox environment."""
 
     def __init__(self, create_args: ToxEnvCreateArgs) -> None:
-        """Create a new tox environment.
+        """
+        Create a new tox environment.
 
         :param create_args: tox env create args
         """
@@ -68,8 +94,6 @@ class ToxEnv(ABC):
         self._interrupted = False
         self._log_id = 0
 
-        self.register_config()
-
     @property
     def cache(self) -> Info:
         return Info(self.env_dir)
@@ -90,7 +114,7 @@ class ToxEnv(ABC):
         raise NotImplementedError
 
     def _install(self, arguments: Any, section: str, of_type: str) -> None:
-        from tox.plugin.manager import MANAGER
+        from tox.plugin.manager import MANAGER  # noqa: PLC0415
 
         MANAGER.tox_on_install(self, arguments, section, of_type)
         self.installer.install(arguments, section, of_type)
@@ -106,26 +130,26 @@ class ToxEnv(ABC):
         )
         self.conf.add_config(
             keys=["labels"],
-            of_type=Set[str],
+            of_type=set[str],
             default=set(),
             desc="labels attached to the tox environment",
         )
         self.conf.add_config(
             keys=["env_dir", "envdir"],
             of_type=Path,
-            default=lambda conf, name: cast(Path, conf.core["work_dir"]) / self.name,  # noqa: U100
+            default=lambda conf, name: cast("Path", conf.core["work_dir"]) / self.name,  # noqa: ARG005
             desc="directory assigned to the tox environment",
         )
         self.conf.add_config(
             keys=["env_tmp_dir", "envtmpdir"],
             of_type=Path,
-            default=lambda conf, name: cast(Path, conf.core["work_dir"]) / self.name / "tmp",  # noqa: U100
+            default=lambda conf, name: cast("Path", conf.core["work_dir"]) / self.name / "tmp",  # noqa: ARG005
             desc="a folder that is always reset at the start of the run",
         )
         self.conf.add_config(
             keys=["env_log_dir", "envlogdir"],
             of_type=Path,
-            default=lambda conf, name: cast(Path, conf.core["work_dir"]) / self.name / "log",  # noqa: U100
+            default=lambda conf, name: cast("Path", conf.core["work_dir"]) / self.name / "log",  # noqa: ARG005
             desc="a folder for logging where tox will put logs of tool invocation",
         )
         self.executor.register_conf(self)
@@ -139,20 +163,21 @@ class ToxEnv(ABC):
 
         def pass_env_post_process(values: list[str]) -> list[str]:
             values.extend(self._default_pass_env())
-            result = sorted({k: None for k in values}.keys())
+            result = sorted(dict.fromkeys(values).keys())
             invalid_chars = set(string.whitespace)
             invalid = [v for v in result if any(c in invalid_chars for c in v)]
             if invalid:
                 invalid_repr = ", ".join(repr(i) for i in invalid)
-                raise Fail(
-                    f"pass_env values cannot contain whitespace, use comma to have multiple values in a single line, "
-                    f"invalid values found {invalid_repr}",
+                msg = (
+                    f"pass_env values cannot contain whitespace, use comma to have multiple values in a single line,"
+                    f" invalid values found {invalid_repr}"
                 )
+                raise Fail(msg)
             return result
 
         self.conf.add_config(
             keys=["pass_env", "passenv"],
-            of_type=List[str],
+            of_type=list[str],
             default=[],
             desc="environment variables to pass on to the tox environment",
             post_process=pass_env_post_process,
@@ -171,38 +196,38 @@ class ToxEnv(ABC):
         )
         self.conf.add_config(
             "allowlist_externals",
-            of_type=List[str],
+            of_type=list[str],
             default=[],
             desc="external command glob to allow calling",
         )
-        assert self.installer is not None  # trigger installer creation to allow configuration registration
+        assert self.installer is not None  # noqa: S101 # trigger installer creation to allow config registration
 
-    def _recreate_default(self, conf: Config, value: str | None) -> bool:  # noqa: U100
-        return cast(bool, self.options.recreate)
+    def _recreate_default(self, conf: Config, value: str | None) -> bool:  # noqa: ARG002
+        return cast("bool", self.options.recreate)
 
     @property
     def env_dir(self) -> Path:
         """:return: the tox environments environment folder"""
-        return cast(Path, self.conf["env_dir"])
+        return cast("Path", self.conf["env_dir"])
 
     @property
     def env_tmp_dir(self) -> Path:
         """:return: the tox environments temp folder"""
-        return cast(Path, self.conf["env_tmp_dir"])
+        return cast("Path", self.conf["env_tmp_dir"])
 
     @property
     def env_log_dir(self) -> Path:
         """:return: the tox environments log folder"""
-        return cast(Path, self.conf["env_log_dir"])
+        return cast("Path", self.conf["env_log_dir"])
 
     @property
     def name(self) -> str:
-        return cast(str, self.conf["env_name"])
+        return cast("str", self.conf["env_name"])
 
-    def _default_set_env(self) -> dict[str, str]:
+    def _default_set_env(self) -> dict[str, str]:  # noqa: PLR6301
         return {}
 
-    def _default_pass_env(self) -> list[str]:
+    def _default_pass_env(self) -> list[str]:  # noqa: PLR6301
         env = [
             "https_proxy",  # HTTP proxy configuration
             "http_proxy",  # HTTP proxy configuration
@@ -218,6 +243,11 @@ class ToxEnv(ABC):
             "CPPFLAGS",  # C++ compiler flags
             "LD_LIBRARY_PATH",  # location of libs
             "LDFLAGS",  # linker flags
+            "HOME",  # needed for `os.path.expanduser()` on non-Windows systems
+            "FORCE_COLOR",  # force color output
+            "NO_COLOR",  # disable color output
+            "NETRC",  # used by pip and netrc modules
+            "PYTHON_GIL",  # allows controlling python gil
         ]
         if sys.stdout.isatty():  # if we're on a interactive shell pass on the TERM
             env.append("TERM")
@@ -229,19 +259,26 @@ class ToxEnv(ABC):
                     "USERPROFILE",  # needed for `os.path.expanduser()`
                     "PATHEXT",  # needed for discovering executables
                     "MSYSTEM",  # controls paths printed format
+                    "WINDIR",  # base path to system executables and DLLs
                 ],
             )
         else:  # pragma: win32 no cover
-            env.append("TMPDIR")  # temporary file location
+            env.extend(
+                [
+                    "TMPDIR",  # temporary file location
+                    "NIX_LD",  # nix-ld loader
+                    "NIX_LD_LIBRARY_PATH",  # nix-ld library path
+                    "SSH_AGENT_PID",  # ssh-agent process ID
+                    "SSH_AUTH_SOCK",  # ssh-agent socket path
+                ],
+            )
         return env
 
     def setup(self) -> None:
-        """
-        Setup the tox environment.
-        """
+        """Setup the tox environment."""
         if self._run_state["setup"] is False:  # pragma: no branch
             self._platform_check()
-            recreate = cast(bool, self.conf["recreate"])
+            recreate = cast("bool", self.conf["recreate"])
             if recreate:
                 self._clean(transitive=True)
             try:
@@ -249,7 +286,7 @@ class ToxEnv(ABC):
                 self._setup_with_env()
             except Recreate as exception:  # once we might try over
                 if not recreate:  # pragma: no cover
-                    logging.warning(f"recreate env because {exception.args[0]}")
+                    logging.warning("recreate env because %s", exception.args[0])
                     self._clean(transitive=False)
                     self._setup_env()
                     self._setup_with_env()
@@ -263,7 +300,7 @@ class ToxEnv(ABC):
             try:
                 self._teardown()
             finally:
-                from tox.plugin.manager import MANAGER
+                from tox.plugin.manager import MANAGER  # noqa: PLC0415
 
                 MANAGER.tox_env_teardown(self)
                 self._run_state["teardown"] = True
@@ -272,12 +309,13 @@ class ToxEnv(ABC):
         pass
 
     def _platform_check(self) -> None:
-        """skip env when platform does not match"""
+        """Skip env when platform does not match."""
         platform_str: str = self.conf["platform"]
         if platform_str:
             match = re.fullmatch(platform_str, self.runs_on_platform)
             if match is None:
-                raise Skip(f"platform {self.runs_on_platform} does not match {platform_str}")
+                msg = f"platform {self.runs_on_platform} does not match {platform_str}"
+                raise Skip(msg)
 
     @property
     @abstractmethod
@@ -292,7 +330,8 @@ class ToxEnv(ABC):
         conf = {"name": self.conf.name, "type": type(self).__name__}
         with self.cache.compare(conf, ToxEnv.__name__) as (eq, old):
             if eq is False and old is not None:  # pragma: no branch  # recreate if already created and not equals
-                raise Recreate(f"env type changed from {old} to {conf}")
+                msg = f"env type changed from {old} to {conf}"
+                raise Recreate(msg)
         self._handle_env_tmp_dir()
         self._handle_core_tmp_dir()
 
@@ -300,10 +339,10 @@ class ToxEnv(ABC):
         pass
 
     def _done_with_setup(self) -> None:  # noqa: B027 # empty abstract base class
-        """called when setup is done"""
+        """Called when setup is done."""
 
     def _handle_env_tmp_dir(self) -> None:
-        """Ensure exists and empty"""
+        """Ensure exists and empty."""
         env_tmp_dir = self.env_tmp_dir
         if env_tmp_dir.exists() and next(env_tmp_dir.iterdir(), None) is not None:
             LOGGER.debug("clear env temp folder %s", env_tmp_dir)
@@ -313,7 +352,7 @@ class ToxEnv(ABC):
     def _handle_core_tmp_dir(self) -> None:
         self.core["temp_dir"].mkdir(parents=True, exist_ok=True)
 
-    def _clean(self, transitive: bool = False) -> None:  # noqa: U100
+    def _clean(self, transitive: bool = False) -> None:  # noqa: ARG002, FBT001, FBT002
         if self._run_state["clean"]:  # pragma: no branch
             return  # pragma: no cover
         env_dir = self.env_dir
@@ -341,15 +380,14 @@ class ToxEnv(ABC):
         result["TOX_ENV_NAME"] = self.name
         result["TOX_WORK_DIR"] = str(self.core["work_dir"])
         result["TOX_ENV_DIR"] = str(self.conf["env_dir"])
+        if (ci := os.environ.get("CI")) is not None:
+            result["__TOX_ENVIRONMENT_VARIABLE_ORIGINAL_CI"] = ci
         return result
 
     @staticmethod
     def _load_pass_env(pass_env: list[str]) -> dict[str, str]:
-        result: dict[str, str] = {}
         patterns = [re.compile(fnmatch.translate(e), re.IGNORECASE) for e in pass_env]
-        for env, value in os.environ.items():
-            if any(p.match(env) for p in patterns):
-                result[env] = value
+        result: dict[str, str] = {e: v for e, v in os.environ.items() if any(p.match(e) for p in patterns)}
         return result
 
     @property
@@ -374,14 +412,13 @@ class ToxEnv(ABC):
     def _make_path(self) -> str:
         values = dict.fromkeys(str(i) for i in self._paths)
         values.update(dict.fromkeys(os.environ.get("PATH", "").split(os.pathsep)))
-        result = os.pathsep.join(values)
-        return result
+        return os.pathsep.join(values)
 
-    def execute(
+    def execute(  # noqa: PLR0913
         self,
         cmd: Sequence[Path | str],
         stdin: StdinSource,
-        show: bool | None = None,
+        show: bool | None = None,  # noqa: FBT001
         cwd: Path | None = None,
         run_id: str = "",
         executor: Execute | None = None,
@@ -401,11 +438,11 @@ class ToxEnv(ABC):
             status.interrupt()
 
     @contextmanager
-    def execute_async(
+    def execute_async(  # noqa: PLR0913
         self,
         cmd: Sequence[Path | str],
         stdin: StdinSource,
-        show: bool | None = None,
+        show: bool | None = None,  # noqa: FBT001
         cwd: Path | None = None,
         run_id: str = "",
         executor: Execute | None = None,
@@ -415,9 +452,9 @@ class ToxEnv(ABC):
         if cwd is None:
             cwd = self.core["tox_root"]
         if show is None:
-            show = self.options.verbosity > 3
+            show = self.options.verbosity > 3  # noqa: PLR2004
         request = ExecuteRequest(cmd, cwd, self.environment_variables, stdin, run_id, allow=self._allow_externals)
-        if _CWD == request.cwd:
+        if request.cwd == _CWD:
             repr_cwd = ""
         else:
             try:
@@ -435,9 +472,9 @@ class ToxEnv(ABC):
                 yield execute_status
             finally:
                 self._execute_statuses.pop(execute_id)
-        if show and self._hidden_outcomes is not None:
-            if execute_status.outcome is not None:  # pragma: no cover # if it gets cancelled before even starting
-                self._hidden_outcomes.append(execute_status.outcome)
+        if show and self._hidden_outcomes is not None and execute_status.outcome is not None:
+            # if it gets canceled before even starting
+            self._hidden_outcomes.append(execute_status.outcome)
         if self.journal and execute_status.outcome is not None:
             self.journal.add_execute(execute_status.outcome, run_id)
         self._log_execute(request, execute_status)
@@ -450,11 +487,16 @@ class ToxEnv(ABC):
 
     @staticmethod
     def _write_execute_log(env_name: str, log_file: Path, request: ExecuteRequest, status: ExecuteStatus) -> None:
+        if not log_file.parent.exists():
+            log_file.parent.mkdir(parents=True, exist_ok=True)
         with log_file.open("wt", encoding="utf-8") as file:
             file.write(f"name: {env_name}\n")
             file.write(f"run_id: {request.run_id}\n")
-            for env_key, env_value in request.env.items():
-                file.write(f"env {env_key}: {env_value}\n")
+            msg = ""
+            for env_key, env_value in sorted(request.env.items()):
+                redacted_value = redact_value(name=env_key, value=env_value)
+                msg += f"env {env_key}: {redacted_value}\n"
+            file.write(msg)
             for meta_key, meta_value in status.metadata.items():
                 file.write(f"metadata {meta_key}: {meta_value}\n")
             file.write(f"cwd: {request.cwd}\n")
@@ -477,7 +519,7 @@ class ToxEnv(ABC):
         executor: Execute,
         out_err: OutErr,
         request: ExecuteRequest,
-        show: bool,
+        show: bool,  # noqa: FBT001
     ) -> Iterator[ExecuteStatus]:
         with executor.call(
             request=request,
@@ -488,18 +530,17 @@ class ToxEnv(ABC):
             yield execute_status
 
     @contextmanager
-    def display_context(self, suspend: bool) -> Iterator[None]:
-        with self._log_context():
-            with self.log_handler.suspend_out_err(suspend, self._suspended_out_err) as out_err:
-                if suspend:  # only set if suspended
-                    self._suspended_out_err = out_err
-                yield
+    def display_context(self, suspend: bool) -> Iterator[None]:  # noqa: FBT001
+        with self._log_context(), self.log_handler.suspend_out_err(suspend, self._suspended_out_err) as out_err:
+            if suspend:  # only set if suspended
+                self._suspended_out_err = out_err
+            yield
 
     def close_and_read_out_err(self) -> tuple[bytes, bytes] | None:
         if self._suspended_out_err is None:  # pragma: no branch
             return None  # pragma: no cover
         (out, err), self._suspended_out_err = self._suspended_out_err, None
-        out_b, err_b = cast(BytesIO, out.buffer).getvalue(), cast(BytesIO, err.buffer).getvalue()
+        out_b, err_b = cast("BytesIO", out.buffer).getvalue(), cast("BytesIO", err.buffer).getvalue()
         out.close()
         err.close()
         return out_b, err_b
